NODATA = -999999;

################################################################################
# THIS FUNCTION EXTRACTS A BALANCED PANEL CONSISTING OF INDIVIDUALS AGED BETWEEN 
# MINAGE AND MAXAGE - RETURNS "selectY"; OPTION DEMEAN -> LOCATION NORMALIZATION
################################################################################

extract_data <- function(MINAGE,MAXAGE,DEMEAN=TRUE){

### Read Data ##################################################################
data <- read.csv("data_trim_r.csv",header=FALSE);
data_id <- data[,1];    ### Individual ID
data_t <- data[,2];     ### Age
data_year <- data[,3];  ### Year
data_Y <- data[,4];     ### Residual

### Set Age = 25 to t=1 ########################################################
min_age = min(data_t);
data_t = data_t - min_age + 1;
T = max( data_t );

### Count N ####################################################################
idx = 1;
curr_id = data_id[1];
for(iter in 1:( dim(data)[1] )){
 if( data_id[iter]!= curr_id ){
  curr_id = data_id[iter];
  idx = idx + 1;
 }
}
N = idx;

### Construct Y Matrix #########################################################
Y = array(NODATA,dim=c(N,T));
idx = 1;
curr_id = data_id[1];
for(iter in 1:( dim(data)[1] )){
 if( data_id[iter]!= curr_id ){
  curr_id = data_id[iter];
  idx = idx + 1;
 }
 Y[idx,data_t[iter]] = data_Y[iter];
}

### Trim by MINAGE and MAX AGE #################################################
selectY = Y[,(MINAGE-min_age+1):(MAXAGE-min_age+1)];

### Extract the Balanced Portion ###############################################
tempY = NULL;
for(iter in 1:N){
 if( min(selectY[iter,]) > NODATA ){
  tempY = rbind(tempY, selectY[iter,]);
 }
}
selectY = tempY;

### Demean (Location Normalization Setting Mean(Y) to Zero for Each t ##########
if(DEMEAN){
 for(iter in 1:( dim(selectY)[2] )){
  selectY[,iter] = selectY[,iter] - mean( selectY[,iter] );
 }
}

return(selectY);
}