source("_extract_data.r");
source("_est_rho_alltogether_parametric.r");
source("_est_phi_v.r");
source("_est_phi_u.r");
source("_est_phi_eta.r");
source("_get_mean.r");
source("_get_variance.r");
source("_fourier.r");
source("_choose_h_normal_reference.r");
source("_compute_moment.r");
source("_est_fuu.r");
source("_est_fvv.r");
source("_est_fuuu.r");
source("_est_fvvv.r");
source("_get_varVrhoV.r");
source("_get_covVrhoV.r");
source("_est_lambda.r");
source("_est_phi_epsilon.r");
source("_est_phi_lambdaepsilon.r");
source("_get_bivariate_normal.r");
source("_get_bivariate_normal_conditional_expectation.r");
source("_get_var_list.r");
source("_stationary_get_var_list.r");
source("_stationary_est_rho_alltogether_parametric.r");
source("_stationary_est_phi_v.r");
source("_stationary_est_phi_u.r");
source("_stationary_est_phi_eta.r");
p = 1;
q = 1;
min_age = 25;
max_age = 55;

################################################################################
# ESTIMATE RHO
################################################################################
polynomial = 3;        ### Degree of Polynomial for Life-Cycle Specification of RHO
rho_list <- est_rho_alltogether_parametric(polynomial,min_age,max_age,p,q);
rho_list = t(matrix(colMeans(rho_list),dim(rho_list)[2],dim(rho_list)[1]));

################################################################################
# ESTIMATE VARIANCES OF U AND V
################################################################################
var_list <- get_var_list(min_age,max_age,p,q,rho_list);
var_u_list = var_list[,1];
var_v_list = var_list[,2];
var_eta_list = var_list[,3];

################################################################################
# ESTIMATE PHI_V, PHI_U, AND PHI_ETA WITH VERY FINE RESOLUTION OF S
################################################################################
coarseness = 0.01;
max_exp = 100 / coarseness;
slist = c(-1*1.05^(-3.3*coarseness*((-1*max_exp):0)), 0, 1.05^(3.3*coarseness*(0:max_exp))) * 0.0001;
phi_v_list <- est_phi_v(min_age,max_age,p,q,slist,rho_list);
phi_u_list <- est_phi_u(min_age,max_age,slist,phi_v_list);
phi_eta_list <- est_phi_eta(min_age,max_age,slist,phi_u_list);

################################################################################
# NOW DISPLAY MARGINAL DISTRIBUTION RESULTS BY "display_marginal_results.r"
################################################################################
source("display_marginal_results.r");

################################################################################
# COMPUTE THE SD, SKEWNESS, AND KURTOSIS OF U AND V BY "estimation_indices.r"
################################################################################
source("estimation_indices.r");

################################################################################
# COMPUTE THE SD, SKEWNESS, AND KURTOSIS OF U AND V BY "estimation_integration_based_indices.r"
################################################################################
source("estimation_integration_based_indices.r");






################################################################################
# NONPARAMETRICALLY COMPUTE IRF AFTER SHOCK AT AGE t BY "estimate_NPIRF.r"
################################################################################
source("display_NPIRF.r");

################################################################################
# NONPARAMETRICALLY COMPUTE VARIANCE IRF AFTER SHOCK AT AGE t BY "estimate_NPIRF_variance.r"
################################################################################
source("display_NPIRF_variance.r");











################################################################################
# ESTIMATE THE JOINT DENSITIES BY "estimation_joint_densities.r" TAKES LONG!!!
################################################################################
source("estimation_joint_densities.r");

################################################################################
# NOW DISPLAY JOINT DISTRIBUTION RESULTS BY "display_joint_results.r"
################################################################################
source("display_joint_results.r");










################################################################################
# ESTIMATE THE LONG-RUN JOINT DENSITIES BY "estimation_longrun_joint.r"
################################################################################
source("estimation_longrun_joint.r");









################################################################################
# THE BELOW PARTS SHOULD BE RUN ONLY UNDER P = 1 AND Q = 1
################################################################################
stationary_rho_list = stationary_est_rho_alltogether_parametric(min_age,max_age);

################################################################################
# ESTIMATE VARIANCES OF U AND V UNDER STATIONARITY OF EPSILON
################################################################################
stationary_var_list <- stationary_get_var_list(min_age,max_age,p,q,stationary_rho_list);
stationary_var_u_list = stationary_var_list[,1];
stationary_var_v_list = stationary_var_list[,2];
stationary_var_eta_list = stationary_var_list[,3];

################################################################################
# ESTIMATE PHI_V, PHI_U, AND PHI_ETA WITH VERY FINE RESOLUTION OF S
# UNDER STATIONARITY OF EPSILON
################################################################################
coarseness = 0.01;
max_exp = 100 / coarseness;
slist = c(-1*1.05^(-3.3*coarseness*((-1*max_exp):0)), 0, 1.05^(3.3*coarseness*(0:max_exp))) * 0.0001;
#stationary_phi_v_list <- stationary_est_phi_v(min_age,max_age,p,q,slist,stationary_rho_list);
stationary_phi_v_list <- est_phi_v(min_age,max_age,p,q,slist,stationary_rho_list);
stationary_phi_u_list <- est_phi_u(min_age,max_age,slist,stationary_phi_v_list);
#stationary_phi_eta_list <- est_phi_eta(min_age,max_age,slist,stationary_phi_u_list);
stationary_phi_eta_list <- stationary_est_phi_eta(min_age,max_age,slist,stationary_phi_u_list);
stationary_phi_u_list <- stationary_est_phi_u(min_age,max_age,slist,stationary_phi_u_list,stationary_phi_eta_list);
stationary_phi_v_list <- stationary_est_phi_v(min_age,max_age,slist,stationary_phi_u_list);

################################################################################
# NOW DISPLAY MARGINAL DISTRIBUTION RESULTS BY "display_marginal_results.r"
################################################################################
source("stationary_display_marginal_results.r");









################################################################################
# THE BELOW PARTS SHOULD BE RUN ONLY UNDER P = 1 AND Q = 1
################################################################################

################################################################################
# ESTIMATE THE MA STRUCTURE BY "estimation_ma.r"
################################################################################
source("estimation_ma.r");

################################################################################
# NOW DISPLAY MA STRUCTURE UNDER ARMA(1,1) BY "display_ma_results.r"
################################################################################
source("display_ma_results.r");




