################################################################################
# DISPLAY RHOS #################################################################
options("scipen"=100, "digits"=3)
rho_list; ### Rows = Age, Cols = Order P
plot(min_age:max_age,rho_list[,1],type="l",lty=1,ylim=c(0,1),xlab=expression(paste("Age ", t)),ylab=expression(paste("AR Coefficient(s)  ",rho[t])));
if(dim(rho_list)[2]>1){
 for(iter in 2:(dim(rho_list)[2])){
  par(new = TRUE);
  plot(min_age:max_age,rho_list[,iter],type="l",lty=iter,ylim=c(0,1),xlab="",ylab="");
 }
}
legend(min_age,1,paste("AR Order ",1:p),lty=1:p);

limit_int = 2.5;
minY = -1 * limit_int;
maxY =  1 * limit_int;

################################################################################
# DISPLAY DENSITIES OF U ACROSS MULTIPLE AGES ##################################
agelist = c(30,40,50);
undersmooth = 0.0;
ulist = -100:100/100 * limit_int;
ulist = ulist[(1+sum(ulist < minY)):length(ulist)];
ulist = ulist[1:(length(ulist)-sum(ulist > maxY))];
ulist_interval = ulist[2] - ulist[1]
xlimmin = -1 * limit_int;
xlimmax =  1 * limit_int;
ylimmin = 0.0;
ylimmax = 1.1;
fulist = ulist * 0;
t = agelist[1];
h = choose_h_normal_reference(ulist,phi_u_list[t-min_age+1,],slist,var_u_list[t-min_age+1]);
h = h * (1 - undersmooth);
for( iter in 1:length(ulist) ){
 fulist[iter] = fourier(ulist[iter],phi_u_list[t-min_age+1,],slist,h,TRUE);
}
fulist = fulist / sum(fulist*(ulist[2]-ulist[1]));
plot(ulist,fulist,type="l",xlim=c(xlimmin,xlimmax),ylim=c(ylimmin,ylimmax),xlab=expression(U[t]),ylab="Density");
for( jter in 2:length(agelist) ){
 fulist = ulist * 0;
 t = agelist[jter];
 h = choose_h_normal_reference(ulist,phi_u_list[t-min_age+1,],slist,var_u_list[t-min_age+1]);
 h = h * (1 - undersmooth);

 for( iter in 1:length(ulist) ){
  fulist[iter] = fourier(ulist[iter],phi_u_list[t-min_age+1,],slist,h,TRUE);
 }
 fulist = fulist / sum(fulist*(ulist[2]-ulist[1]));
 par(new=TRUE);
 plot(ulist,fulist,type="l",lty=jter,xlim=c(xlimmin,xlimmax),ylim=c(ylimmin,ylimmax),xlab="",ylab="");
}
legend(xlimmin,ylimmax,paste("t =",agelist),lty=order(agelist));

################################################################################
# DISPLAY DENSITIES OF U FOR ONE AGE WITH NORMAL REFERENCE #####################
t = 30;
undersmooth = 0.0;
ulist = -100:100/100 * limit_int;
ulist = ulist[(1+sum(ulist < minY)):length(ulist)];
ulist = ulist[1:(length(ulist)-sum(ulist > maxY))];
ulist_interval = ulist[2] - ulist[1]
xlimmin = -1 * limit_int;
xlimmax =  1 * limit_int;
ylimmin = 0.0;
ylimmax = 1.2;
fulist = ulist * 0;
h = choose_h_normal_reference(ulist,phi_u_list[t-min_age+1,],slist,var_u_list[t-min_age+1]);
h = h * (1 - undersmooth);
for( iter in 1:length(ulist) ){
 fulist[iter] = fourier(ulist[iter],phi_u_list[t-min_age+1,],slist,h,TRUE);
}
fulist = fulist / sum(fulist*(ulist[2]-ulist[1]));
plot(ulist,fulist,type="l",xlim=c(xlimmin,xlimmax),ylim=c(ylimmin,ylimmax),xlab=expression(U[t]),ylab="Density");
par(new=TRUE);
plot(ulist,dnorm(ulist,0,var_u_list[t-min_age+1]^.5),type="l",lty=2,xlim=c(xlimmin,xlimmax),ylim=c(ylimmin,ylimmax),xlab="",ylab="");
legend(xlimmin,ylimmax,paste(c("Kernel t =","Normal t ="),t),lty=c(1,2));

################################################################################
# DISPLAY DENSITIES OF V ACROSS MULTIPLE AGES ##################################
agelist = c(30,40,50);
undersmooth = 0.0;
vlist = -100:100/100 * limit_int;
vlist = vlist[(1+sum(vlist < minY)):length(vlist)];
vlist = vlist[1:(length(vlist)-sum(vlist > maxY))];
vlist_interval = vlist[2] - vlist[1]
xlimmin = -1 * limit_int;
xlimmax =  1 * limit_int;
ylimmin = -0.0;
ylimmax = 1.75;
fvlist = vlist * 0;
t = agelist[1];
h = choose_h_normal_reference(vlist,phi_v_list[t-min_age+1,],slist,var_v_list[t-min_age+1]);
h = h * (1 - undersmooth);
for( iter in 1:length(vlist) ){
 fvlist[iter] = fourier(vlist[iter],phi_v_list[t-min_age+1,],slist,h,TRUE);
}
fvlist = fvlist / sum(fvlist*(vlist[2]-vlist[1]));
plot(vlist,fvlist,type="l",xlim=c(xlimmin,xlimmax),ylim=c(ylimmin,ylimmax),xlab=expression(V[t]),ylab="Density");
for( jter in 2:length(agelist) ){
 fvlist = vlist * 0;
 t = agelist[jter];
 h = choose_h_normal_reference(vlist,phi_v_list[t-min_age+1,],slist,var_v_list[t-min_age+1]);
 h = h * (1 - undersmooth); 
 for( iter in 1:length(vlist) ){
  fvlist[iter] = fourier(vlist[iter],phi_v_list[t-min_age+1,],slist,h,TRUE);
 }
 fvlist = fvlist / sum(fvlist*(vlist[2]-vlist[1]));
 par(new=TRUE);
 plot(vlist,fvlist,type="l",lty=jter,xlim=c(xlimmin,xlimmax),ylim=c(ylimmin,ylimmax),xlab="",ylab="");
}
legend(xlimmin,ylimmax,paste("t =",agelist),lty=order(agelist));

################################################################################
# DISPLAY DENSITIES OF V FOR ONE AGE WITH NORMAL REFERENCE #####################
t = 30;
undersmooth = 0.0;
vlist = -100:100/100 * limit_int;
vlist = vlist[(1+sum(vlist < minY)):length(vlist)];
vlist = vlist[1:(length(vlist)-sum(vlist > maxY))];
vlist_interval = vlist[2] - vlist[1]
xlimmin = -1 * limit_int;
xlimmax =  1 * limit_int;
ylimmin = -0.0;
ylimmax = 1.75;
fvlist = vlist * 0;
h = choose_h_normal_reference(vlist,phi_v_list[t-min_age+1,],slist,var_v_list[t-min_age+1]);
h = h * (1 - undersmooth); 
for( iter in 1:length(vlist) ){
 fvlist[iter] = fourier(vlist[iter],phi_v_list[t-min_age+1,],slist,h,TRUE);
}
fvlist = fvlist / sum(fvlist*(vlist[2]-vlist[1]));
plot(vlist,fvlist,type="l",xlim=c(xlimmin,xlimmax),ylim=c(ylimmin,ylimmax),xlab=expression(V[t]),ylab="Density");
par(new=TRUE);
plot(vlist,dnorm(vlist,0,var_v_list[t-min_age+1]^.5),type="l",lty=2,xlim=c(xlimmin,xlimmax),ylim=c(ylimmin,ylimmax),xlab="",ylab="");
legend(xlimmin,ylimmax,paste(c("Kernel t =","Normal t ="),t),lty=c(1,2));

################################################################################
# DISPLAY DENSITIES OF ETA ACROSS MULTIPLE AGES ################################
agelist = c(30,40,50);
undersmooth = 0.0;
etalist = -100:100/100 * limit_int;
xlimmin = -1 * limit_int;
xlimmax =  1 * limit_int;
ylimmin = -0.0;
ylimmax = 2.75;
fetalist = etalist * 0;
t = agelist[1];
h = choose_h_normal_reference(etalist,phi_eta_list[t-min_age+1,],slist,NULL);
h = h * (1 - undersmooth); 
for( iter in 1:length(etalist) ){
 fetalist[iter] = fourier(etalist[iter],phi_eta_list[t-min_age+1,],slist,h,TRUE);
}
fetalist = fetalist / sum(fetalist*(etalist[2]-etalist[1]));
plot(etalist,fetalist,type="l",xlim=c(xlimmin,xlimmax),ylim=c(ylimmin,ylimmax),xlab=expression(eta[t]),ylab="Density");
for( jter in 2:length(agelist) ){
 fetalist = etalist * 0;
 t = agelist[jter];
 h = choose_h_normal_reference(etalist,phi_eta_list[t-min_age+1,],slist,var_eta_list[t-min_age+1]);
 h = h * (1 - undersmooth); 
 for( iter in 1:length(etalist) ){
  fetalist[iter] = fourier(etalist[iter],phi_eta_list[t-min_age+1,],slist,h,TRUE);
 }
 fetalist = fetalist / sum(fetalist*(etalist[2]-etalist[1]));
 par(new=TRUE);
 plot(etalist,fetalist,type="l",lty=jter,xlim=c(xlimmin,xlimmax),ylim=c(ylimmin,ylimmax),xlab="",ylab="");
}
legend(xlimmin,ylimmax,paste("t =",agelist),lty=order(agelist));

################################################################################
# DISPLAY DENSITIES OF ETA ACROSS MULTIPLE AGES ################################
agelist = c(30,40);
delta_t=10;
undersmooth = 0.0;
etalist = -50:50/50 * limit_int;
xlimmin = -1 * limit_int;
xlimmax =  1 * limit_int;
ylimmin = -0.0;
ylimmax = 2.75;
fetalist = etalist * 0;
t = agelist[1];
curr_phi_eta_list = exp( colSums( log( phi_eta_list[(t-min_age+1):(t-min_age+delta_t),] ) ) );
h = choose_h_normal_reference(etalist,curr_phi_eta_list,slist,NULL);
h = h * (1 - undersmooth); 
for( iter in 1:length(etalist) ){
 fetalist[iter] = fourier(etalist[iter],curr_phi_eta_list,slist,h,TRUE);
}
fetalist = fetalist / sum(fetalist*(etalist[2]-etalist[1]));
plot(etalist,fetalist,type="l",xlim=c(xlimmin,xlimmax),ylim=c(ylimmin,ylimmax),xlab=expression(paste(Sigma[t],eta[t])),ylab="Density");
for( jter in 2:length(agelist) ){
 fetalist = etalist * 0;
 t = agelist[jter];
 curr_phi_eta_list = exp( colSums( log( phi_eta_list[(t-min_age+1):(t-min_age+delta_t),] ) ) );
 h = choose_h_normal_reference(etalist,phi_eta_list[t-min_age+1,],slist,var_eta_list[t-min_age+1]);
 h = h * (1 - undersmooth); 
 for( iter in 1:length(etalist) ){
  fetalist[iter] = fourier(etalist[iter],phi_eta_list[t-min_age+1,],slist,h,TRUE);
 }
 fetalist = fetalist / sum(fetalist*(etalist[2]-etalist[1]));
 par(new=TRUE);
 plot(etalist,fetalist,type="l",lty=jter,xlim=c(xlimmin,xlimmax),ylim=c(ylimmin,ylimmax),xlab="",ylab="");
}
legend(xlimmin,ylimmax,paste("t from",agelist,"to",agelist+delta_t),lty=order(agelist));

################################################################################
# DISPLAY DENSITIES OF ETA FOR ONE AGE WITH NORMAL REFERENCE ###################
t = 30;
undersmooth = 0.0;
etalist = -50:50/50 * 0.5;
xlimmin = -0.5;
xlimmax = 0.5;
ylimmin = -0.0;
ylimmax = 2.75;
fetalist = etalist * 0;
h = choose_h_normal_reference(etalist,phi_eta_list[t-min_age+1,],slist,NULL);
h = h * (1 - undersmooth); 
for( iter in 1:length(etalist) ){
 fetalist[iter] = fourier(etalist[iter],phi_eta_list[t-min_age+1,],slist,h,TRUE);
}
fetalist = fetalist / sum(fetalist*(etalist[2]-etalist[1]));
plot(etalist,fetalist,type="l",xlim=c(xlimmin,xlimmax),ylim=c(ylimmin,ylimmax),xlab=expression(eta[t]),ylab="Density");
par(new=TRUE);
plot(etalist,dnorm(etalist,compute_moment(etalist,fetalist,1),compute_moment(etalist,fetalist,2)^0.5),type="l",lty=2,xlim=c(xlimmin,xlimmax),ylim=c(ylimmin,ylimmax),xlab="",ylab="");
legend(xlimmin,ylimmax,paste(c("Kernel t =","Normal t ="),t),lty=c(1,2));

################################################################################
# DISPLAY DENSITIES OF ETA FOR ONE AGE WITH NORMAL REFERENCE ###################
t = 30;
delta_t=10;
undersmooth = 0.0;
etalist = -50:50/50 * 0.5;
xlimmin = -0.5;
xlimmax = 0.5;
ylimmin = -0.0;
ylimmax = 2.75;
fetalist = etalist * 0;
curr_phi_eta_list = exp( colSums( log( phi_eta_list[(t-min_age+1):(t-min_age+delta_t),] ) ) );
h = choose_h_normal_reference(etalist,curr_phi_eta_list,slist,NULL);
h = h * (1 - undersmooth); 
for( iter in 1:length(etalist) ){
 fetalist[iter] = fourier(etalist[iter],curr_phi_eta_list,slist,h,TRUE);
}
fetalist = fetalist / sum(fetalist*(etalist[2]-etalist[1]));
plot(etalist,fetalist,type="l",xlim=c(xlimmin,xlimmax),ylim=c(ylimmin,ylimmax),xlab=expression(paste(Sigma[t],eta[t])),ylab="Density");
par(new=TRUE);
plot(etalist,dnorm(etalist,compute_moment(etalist,fetalist,1),compute_moment(etalist,fetalist,2)^0.5),type="l",lty=2,xlim=c(xlimmin,xlimmax),ylim=c(ylimmin,ylimmax),xlab="",ylab="");
legend(xlimmin,ylimmax,paste(c("Kernel t from","Normal t from"),t,"to",t+delta_t),lty=c(1,2));
