horizon = 50;
delta_t_list = 1:(horizon-t);

lim=c(-0.6,0.6)
IRF_var_V = matrix(0,t-min_age,101);
vlist = -50:50/50 * 0.5#0.75;
IRF_var_V = rbind( IRF_var_V, matrix( 0, 1, length(vlist)) )
plot(vlist, 0*vlist, type="l", lty=1, xlim=lim, ylim=lim, xlab=paste("Transotory Earnings at Age ", t), ylab="Expected Future Transitory Earnings")
for( delta_iter in 1:length(delta_t_list) ){
delta_t = delta_t_list[ delta_iter ];  ### Years After

################################################################################
# ESTIMATE PHI_V, PHI_U, AND PHI_ETA WITH COARSE RESOLUTION OF S
################################################################################
coarseness = 1.0;
max_exp = 100 / coarseness;
slist_coarse = c(-1*1.05^(-3.3*coarseness*((-1*max_exp):0)), 0, 1.05^(3.3*coarseness*(0:max_exp))) * 0.0001;
phi_v_list_coarse <- est_phi_v(min_age,max_age,p,q,slist_coarse,rho_list);
phi_u_list_coarse <- est_phi_u(min_age,max_age,slist_coarse,phi_v_list_coarse);
phi_eta_list_coarse <- est_phi_eta(min_age,max_age,slist_coarse,phi_u_list_coarse);

age_list = min_age:(max_age-q-1-3);
ulist_coarse = -25:25/25 * 1.0;
vlist_coarse = -15:15/25 * 1.0;

################################################################################
# FIRST ESTIMATE THE MARGINALS OF BASELINE U AND LONG-RUN SUM OF ETAS
################################################################################
phi_sumeta = array(0,length(slist_coarse));
for(iter in 1:length(slist_coarse)){
 phi_sumeta[iter] = phi_u_list_coarse[(t-min_age+1+delta_t),iter] / phi_u_list_coarse[(t-min_age+1),iter];
}

ulist = -50:50/50 * 1.0;
fulist = ulist * 0;
h = choose_h_normal_reference(ulist,phi_u_list_coarse[t-min_age+1,],slist_coarse,var_u_list[t-min_age+1]);
for( iter in 1:length(ulist) ){
 fulist[iter] = fourier(ulist[iter],phi_u_list_coarse[t-min_age+1,],slist_coarse,h,TRUE);
}

sumetalist = (-1*length(ulist)):length(ulist) * (ulist[2]-ulist[1])
fsumetalist = sumetalist * 0;
h = choose_h_normal_reference(sumetalist,phi_sumeta,slist_coarse,NULL);
for( iter in 1:length(sumetalist) ){
 fsumetalist[iter] = fourier(sumetalist[iter],phi_sumeta,slist_coarse,h,TRUE);
}

################################################################################
# SECOND, ESTIMATE THE LONG-RUN JOINT OF U
################################################################################
fuu_longrun = array(0,dim=c(length(ulist),length(ulist)));
for(iter in 1:length(ulist)){
 for(jter in 1:length(ulist)){
  eta2 = ulist[jter] - ulist[iter];
  eta2idx = order(abs(sumetalist - eta2))[1];
  fuu_longrun[iter,jter] = fulist[iter] * fsumetalist[eta2idx];
 }
}
fuu_longrun = (Re(fuu_longrun) > 0) * Re(fuu_longrun) + (Re(fuu_longrun) <= 0) * fuu_longrun * 0;
fuu_longrun = Re(fuu_longrun) / sum( Re(fuu_longrun)*(ulist[2]-ulist[1])^2 );

################################################################################
# THIRD, ESTIMATE THE LONG-RUN JOINT OF V
################################################################################
extract = extract_data(t,t+delta_t,TRUE);

uu = array(ulist,dim=c(length(ulist),length(ulist)));

phi_vv_list = array(0,dim=c(length(slist_coarse),length(slist_coarse)));
for(iter in 1:length(slist_coarse)){
 for(jter in 1:length(slist_coarse)){
  s1 = slist_coarse[iter];
  s2 = slist_coarse[jter];
  num = mean( exp(1i*s1*extract[,1] + 1i*s2*extract[,1+delta_t]) );
  den = sum( exp(1i*s1*uu + 1i*s2*t(uu)) * fuu_longrun * (ulist[2]-ulist[1])^2 );
  phi_vv_list[iter,jter] = num / den;
 }
}

middle_s_idx = (length(slist_coarse)+1)/2;
temp_slist_interval = slist_coarse[2:length(slist_coarse)] - slist_coarse[1:(length(slist_coarse)-1)];
slist_interval = c(temp_slist_interval[1:(middle_s_idx-1)], temp_slist_interval[middle_s_idx], temp_slist_interval[middle_s_idx:length(temp_slist_interval)]);
s1mat = array(slist_coarse,dim=c(length(slist_coarse),length(slist_coarse)));
s2mat = t(array(slist_coarse,dim=c(length(slist_coarse),length(slist_coarse))));

vlist = -50:50/50 * 0.5#0.75;
hlist = 1:25/100;
min_h = 0;
min_ise = 999999;
var_v = get_variance(phi_v_list_coarse[t-min_age+1,],slist_coarse)
for(hter in 1:length(hlist)){
 h = hlist[hter];
 fv = array(0,length(vlist));
 for(iter in 1:length(vlist)){
  v1 = vlist[iter];
  v2 = 0;
  fv[iter] = sum( exp(-1i*s1mat*v1 -1i*s2mat*v2) * phi_vv_list * ker( h*s1mat ) * ker( h*s2mat ) * (slist_interval%*%t(slist_interval)) ) * 1/2^2/3.14159^2;
  fv[iter] = Re(fv[iter]);
 }
 ise = sum( ( Re(fv) - dnorm(vlist,0,var_v^.5) )^2 );
 if( ise < min_ise ){
  min_ise = ise;
  min_h = h;
 }
}

h = min_h
fvv_longrun = array(0,dim=c(length(vlist),length(vlist)));
for(iter in 1:length(vlist)){
 for(jter in 1:length(vlist)){
  v1 = vlist[iter];
  v2 = vlist[jter];
  fvv_longrun[iter,jter] = sum( exp(-1i*s1mat*v1 -1i*s2mat*v2) * phi_vv_list * ker( h*s1mat ) * ker( h*s2mat ) * (slist_interval%*%t(slist_interval)) ) * 1/2^2/3.14159^2;
  fvv_longrun[iter,jter] = Re(fvv_longrun[iter,jter]);
 }
}
fvv_longrun = (Re(fvv_longrun) > 0) * fvv_longrun + (Re(fvv_longrun) <= 0) * 0;
fvv_longrun = Re( fvv_longrun / sum( Re(fvv_longrun)*(vlist[2]-vlist[1])^2 ) );

#BR = matrix(1:length(vlist),length(vlist),length(vlist)) + t(matrix(1:length(vlist),length(vlist),length(vlist))) > length(vlist)
#BR[,1] = FALSE
#BR_INC = ( BR * fvv_longrun - cbind(0,( cbind(BR[,2:length(vlist)],0) * fvv_longrun )[,1:(length(vlist)-1)]) > 0 )
#TL = !BR
#TL_DEC = ( cbind(0,TL[,1:(length(vlist)-1)]) * fvv_longrun - TL * fvv_longrun < 0 )
#fvv_longrun = (BR_INC | TL_DEC) * 0 + (!BR_INC & !TL_DEC) * fvv_longrun

nume_V_1 = ( vlist %*% fvv_longrun ) * (vlist[2]-vlist[1])
nume_V_2 = ( vlist^2 %*% fvv_longrun ) * (vlist[2]-vlist[1])
deno_V = ( (vlist*0+1) %*% fvv_longrun ) * (vlist[2]-vlist[1])
par(new=TRUE)
plot(vlist, nume_V_2/deno_V - (nume_V_1/deno_V)^2, type="l", lty=delta_iter+1, xlim=lim, ylim=lim, xlab="", ylab="")
IRF_var_V = rbind( IRF_var_V, matrix( nume_V_2/deno_V - (nume_V_1/deno_V)^2, 1, length(vlist)) )
}
legend(min(lim),max(lim),lty=1:length(delta_t_list)+1,paste("Age ",delta_t_list+t))



IRF_var_V